#ifdef ENABLE_SRP

int _gnutls_srp_recv_params( GNUTLS_STATE state, const opaque* data, int data_size);
int _gnutls_srp_send_params( GNUTLS_STATE state, opaque** data);

#endif
